#[repr(C)]pub struct ChannelKeyword(u16);Expand description
Represents a channel keyword inside a color.
Tuple Fields
0: u16Implementations
Sourceimpl ChannelKeyword
impl ChannelKeyword
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ChannelKeyword
impl ChannelKeyword
Sourcepub const fn iter(&self) -> Iter<ChannelKeyword>
pub const fn iter(&self) -> Iter<ChannelKeyword>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ChannelKeyword>
pub const fn iter_names(&self) -> IterNames<ChannelKeyword>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ChannelKeyword
impl ChannelKeyword
Sourcepub fn rgb() -> Self
pub fn rgb() -> Self
Channel keywords allowed in sRGB colors. https://drafts.csswg.org/css-color-5/#relative-RGB
Sourcepub fn hsl() -> Self
pub fn hsl() -> Self
Channel keywords allowed in HSL colors. https://drafts.csswg.org/css-color-5/#relative-HSL
Sourcepub fn hwb() -> Self
pub fn hwb() -> Self
Channel keywords allowed in HWB colors. https://drafts.csswg.org/css-color-5/#relative-HWB
Sourcepub fn lab() -> Self
pub fn lab() -> Self
Channel keywords allowed in Lab and Oklab colors. https://drafts.csswg.org/css-color-5/#relative-Lab
Sourcepub fn lch() -> Self
pub fn lch() -> Self
Channel keywords allowed in LCH and OkLCh colors. https://drafts.csswg.org/css-color-5/#relative-LCH
Sourcepub fn xyz() -> Self
pub fn xyz() -> Self
Channel keywords allowed in XYZ colors. https://drafts.csswg.org/css-color-5/#relative-color-function
Sourcepub fn from_ident(ident: &str) -> Result<Self, ()>
pub fn from_ident(ident: &str) -> Result<Self, ()>
Parse a channel keyword from an ident.